@@ -169,7 +169,34 @@
 
     names(vals$re) <- re_names
     names(vals$vc) <- re_names
-
+  } else if (inherits(x, "clmm")) {
+    if (requireNamespace("ordinal", quietly = TRUE)) {
+      f <- find_formula(x)$conditional
+      mm <- stats::model.matrix(f, x$model)
+      vals <- list(
+        beta = c("(Intercept)" = 1, stats::coef(x)[intersect(names(coef(x)), colnames(mm))]),
+        X = mm,
+        vc = ordinal::VarCorr(x),
+        re = ordinal::ranef(x)
+      )
+    }
+  } else if (inherits(x, "glmmadmb")) {
+    vals <- list(
+      beta = lme4::fixef(x),
+      X = stats::model.matrix(x),
+      vc = lme4::VarCorr(x),
+      re = lme4::ranef(x)
+    )
+  } else if (inherits(x, "cpglmm")) {
+    if (!requireNamespace("cplm", quietly = TRUE)) {
+      stop("Package 'cplm' required. Please install it.")
+    }
+    vals <- list(
+      beta = cplm::fixef(x),
+      X = cplm::model.matrix(x),
+      vc = cplm::VarCorr(x),
+      re = cplm::ranef(x)
+    )
   } else {
     vals <- list(
       beta = lme4::fixef(x),
@@ -179,8 +206,7 @@
     )
   }
 
-  # for glmmTMB, use conditional component of model only,
-  # and tell user that zero-inflation is ignored
+  # for glmmTMB, tell user that dispersion model is ignored
 
   if (inherits(x, "glmmTMB")) {
     vals <- lapply(vals, .collapse_cond)
@@ -236,8 +262,7 @@
 #
 #' @importFrom stats nobs
 .compute_variance_random <- function(terms, x, vals) {
-
-  sigma_sum <- function(Sigma) {
+  .sigma_sum <- function(Sigma) {
     rn <- rownames(Sigma)
 
     if (!is.null(rn)) {
@@ -254,9 +279,9 @@
   }
 
   if (inherits(x, "MixMod")) {
-    sigma_sum(vals$vc)
+    .sigma_sum(vals$vc)
   } else {
-    sum(sapply(vals$vc[terms], sigma_sum))
+    sum(sapply(vals$vc[terms], .sigma_sum))
   }
 }
 
@@ -265,10 +290,11 @@
 
 # Calculate Distribution-specific variance (Nakagawa et al. 2017)
 .compute_variance_distribution <- function(x, var.cor, faminfo, name, verbose = TRUE) {
-  if (inherits(x, "lme"))
+  if (inherits(x, "lme")) {
     sig <- x$sigma
-  else
+  } else {
     sig <- attr(var.cor, "sc")
+  }
 
   if (is.null(sig)) sig <- 1
 
@@ -283,6 +309,8 @@
         faminfo$link_function,
         logit = pi^2 / 3,
         probit = 1,
+        cloglog = ,
+        clogloglink = pi^2 / 6,
         .badlink(faminfo$link_function, faminfo$family, verbose = verbose)
       )
     } else if (faminfo$is_count) {
@@ -358,7 +386,14 @@
 
   # check if null-model could be computed
   if (!is.null(null_model)) {
-    null_fixef <- unname(.collapse_cond(lme4::fixef(null_model)))
+    if (inherits(null_model, "cpglmm")) {
+      if (!requireNamespace("cplm", quietly = TRUE)) {
+        stop("Package 'cplm' required. Please install it.")
+      }
+      null_fixef <- unname(cplm::fixef(null_model))
+    } else {
+      null_fixef <- unname(.collapse_cond(lme4::fixef(null_model)))
+    }
     mu <- exp(null_fixef)
   } else {
     mu <- NA
@@ -376,44 +411,45 @@
     }
   }
 
-  cvsquared <- tryCatch({
-    vv <- switch(
-      faminfo$family,
+  cvsquared <- tryCatch(
+    {
+      vv <- switch(
+        faminfo$family,
 
-      # (zero-inflated) poisson
-      `zero-inflated poisson` = ,
-      poisson                 = .variance_family_poisson(x, mu, faminfo),
+        # (zero-inflated) poisson
+        `zero-inflated poisson` = ,
+        poisson = .variance_family_poisson(x, mu, faminfo),
 
-      # hurdle-poisson
-      `hurdle poisson`    = ,
-      truncated_poisson   = stats::family(x)$variance(sig),
+        # hurdle-poisson
+        `hurdle poisson` = ,
+        truncated_poisson = stats::family(x)$variance(sig),
 
-      # Gamma, exponential
-      Gamma               = stats::family(x)$variance(sig),
+        # Gamma, exponential
+        Gamma = stats::family(x)$variance(sig),
 
-      # (zero-inflated) negative binomial
-      `zero-inflated negative binomial` = ,
-      `negative binomial` = ,
-      genpois             = ,
-      nbinom1             = ,
-      nbinom2             = .variance_family_nbinom(x, mu, sig, faminfo),
+        # (zero-inflated) negative binomial
+        `zero-inflated negative binomial` = ,
+        `negative binomial` = ,
+        genpois = ,
+        nbinom1 = ,
+        nbinom2 = .variance_family_nbinom(x, mu, sig, faminfo),
 
-      # other distributions
-      tweedie             = .variance_family_tweedie(x, mu, sig),
-      beta                = .variance_family_beta(x, mu, sig),
+        # other distributions
+        tweedie = .variance_family_tweedie(x, mu, sig),
+        beta = .variance_family_beta(x, mu, sig),
 
-      # default variance for non-captured distributions
-      .variance_family_default(x, mu, verbose)
-    )
+        # default variance for non-captured distributions
+        .variance_family_default(x, mu, verbose)
+      )
 
-    vv / mu^2
-  },
-  error = function(x) {
-    if (verbose) {
-      warning("Can't calculate model's distribution-specific variance. Results are not reliable.", call. = F)
+      vv / mu^2
+    },
+    error = function(x) {
+      if (verbose) {
+        warning("Can't calculate model's distribution-specific variance. Results are not reliable.", call. = F)
+      }
+      0
     }
-    0
-  }
   )
 
   log1p(cvsquared)
@@ -424,11 +460,13 @@
 
 # Get distributional variance for poisson-family
 .variance_family_poisson <- function(x, mu, faminfo) {
-  if (faminfo$is_zeroinf) {
+  if (faminfo$is_zero_inflated) {
     .variance_zip(x, faminfo, family_var = mu)
   } else {
     if (inherits(x, "MixMod")) {
       return(mu)
+    } else if (inherits(x, "cpglmm")) {
+      .get_cplm_family(x)$variance(mu)
     } else {
       stats::family(x)$variance(mu)
     }
@@ -440,10 +478,11 @@
 
 # Get distributional variance for beta-family
 .variance_family_beta <- function(x, mu, phi) {
-  if (inherits(x, "MixMod"))
+  if (inherits(x, "MixMod")) {
     stats::family(x)$variance(mu)
-  else
+  } else {
     mu * (1 - mu) / (1 + phi)
+  }
 }
 
 
@@ -462,13 +501,14 @@
 
 # Get distributional variance for nbinom-family
 .variance_family_nbinom <- function(x, mu, sig, faminfo) {
-  if (faminfo$is_zeroinf) {
+  if (faminfo$is_zero_inflated) {
     if (missing(sig)) sig <- 0
     .variance_zinb(x, sig, faminfo, family_var = mu * (1 + sig))
   } else {
     if (inherits(x, "MixMod")) {
-      if (missing(sig))
+      if (missing(sig)) {
         return(rep(1e-16, length(mu)))
+      }
       mu * (1 + sig)
     } else {
       stats::family(x)$variance(mu, sig)
@@ -550,21 +590,23 @@
     stop("Package `lme4` needs to be installed to compute variances for mixed models.", call. = FALSE)
   }
 
-  tryCatch({
-    if (inherits(x, "merMod")) {
-      mu * (1 + mu / lme4::getME(x, "glmer.nb.theta"))
-    } else if (inherits(x, "MixMod")) {
-      stats::family(x)$variance(mu)
-    } else {
-      mu * (1 + mu / x$theta)
+  tryCatch(
+    {
+      if (inherits(x, "merMod")) {
+        mu * (1 + mu / lme4::getME(x, "glmer.nb.theta"))
+      } else if (inherits(x, "MixMod")) {
+        stats::family(x)$variance(mu)
+      } else {
+        mu * (1 + mu / x$theta)
+      }
+    },
+    error = function(x) {
+      if (verbose) {
+        warning("Can't calculate model's distribution-specific variance. Results are not reliable.", call. = F)
+      }
+      0
     }
-  },
-  error = function(x) {
-    if (verbose) {
-      warning("Can't calculate model's distribution-specific variance. Results are not reliable.", call. = F)
-    }
-    0
-  })
+  )
 }
 
 
@@ -583,12 +625,16 @@
   if (inherits(model, "MixMod")) {
     nullform <- stats::as.formula(paste(find_response(model), "~ 1"))
     null.model <- stats::update(model, fixed = nullform)
+  } else if (inherits(model, "cpglmm")) {
+    nullform <- find_formula(model)[["random"]]
+    null.model <- stats::update(model, nullform)
   } else {
     f <- stats::formula(model)
     resp <- find_response(model)
     re.terms <- paste0("(", sapply(lme4::findbars(f), .safe_deparse), ")")
     nullform <- stats::reformulate(re.terms, response = resp)
-    null.model <- tryCatch({
+    null.model <- tryCatch(
+      {
         stats::update(model, nullform)
       },
       error = function(e) {
@@ -618,7 +664,9 @@
 
   # if model has no random slopes, there are no random slopes that
   # are *not* present as fixed effects
-  if (is.null(rs)) return(TRUE)
+  if (is.null(rs)) {
+    return(TRUE)
+  }
 
   # make sure we have identical subcomponents between random and
   # fixed effects
@@ -676,10 +724,11 @@
   } else {
     corrs <- lapply(vals$vc, attr, "correlation")
     rho01 <- sapply(corrs, function(i) {
-      if (!is.null(i))
+      if (!is.null(i)) {
         i[-1, 1]
-      else
+      } else {
         NULL
+      }
     })
     unlist(rho01)
   }
